| Title: | Frequency Distribution |
|---|---|
| Description: | Generates a frequency distribution. The frequency distribution includes raw frequencies, percentages in each category, and cumulative frequencies. The frequency distribution can be stored as a data frame. |
| Authors: | Thomas Feldman <[email protected]> and Kenneth W. Moffett <[email protected]> |
| Maintainer: | Kenneth W. Moffett <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1 |
| Built: | 2026-05-26 09:14:19 UTC |
| Source: | https://github.com/cran/freqdist |
Generates a Frequency Distribution with columns for raw frequencies, percentages, and cumulative percentages.
freqdist(x)freqdist(x)
x |
Variable on which the frequency distribution is generated. |
- Returns the frequency distribution.
Thomas Feldman and Kenneth W. Moffett
# Create Sample Data Frame data <- c(1,2,3,4,4) data <- as.data.frame(data) # Run Frequency Distribution Command on Data Frame freqdist(data)# Create Sample Data Frame data <- c(1,2,3,4,4) data <- as.data.frame(data) # Run Frequency Distribution Command on Data Frame freqdist(data)